@@ -3,20 +3,13 @@ from urllib.parse import unquote, urlparse
 
 from bs4 import BeautifulSoup
 
-from nadf.decorator.check_namuwiki_url import check_namuwiki_url
 
 
 class HtmlParser:
-    @check_namuwiki_url()
     def __init__(self, html: BeautifulSoup, url: str):
         self.soup = html
         self.url = url
 
-
-    async def extract_name(self):
-        slug = unquote(urlparse(self.url).path.rsplit("/", 1)[-1])
-        return slug.replace("_", " ").strip()
-
     async def extract_small_topics(self) -> List[Tuple[str, str, str]]:  # 레벨 추가
         small_topics = self.soup.find_all(['h2', 'h3', 'h4'])
         small_topics_list = []
